==> SimpleWhois-0.0.1.tar.gz: SimpleWhois-0.0.1/setup.py <==
from setuptools import setup, find_packages
import SimpleWhois as package

setup(
    name='SimpleWhois',
    version=package.__version__,
    py_modules=['SimpleWhois'],
    packages=find_packages(include=[]),
    install_requires=[],
    scripts=[],
    author="Maurice Lambert",
    author_email="mauricelambert434@gmail.com",
    maintainer="Maurice Lambert",
    maintainer_email="mauricelambert434@gmail.com",
    description='This module implements WHOIS protocol and performs WHOIS requests.',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/mauricelambert/SimpleWhois",
    project_urls={
        "Github": "https://github.com/mauricelambert/SimpleWhois",
        "Documentation": "https://mauricelambert.github.io/info/python/code/SimpleWhois.html",
        "Python Executable": "https://mauricelambert.github.io/info/python/code/SimpleWhois.pyz",
        "Windows Executable": "https://mauricelambert.github.io/info/python/code/SimpleWhois.exe",
    },
    download_url="https://mauricelambert.github.io/info/python/code/SimpleWhois.pyz",
    include_package_data=True,
    classifiers=[
        "Topic :: System",
        "Topic :: Software Development :: Libraries",
        "Environment :: Console",
        "Topic :: System :: Shells",
        'Operating System :: POSIX',
        "Natural Language :: English",
        "Topic :: System :: Networking",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "Topic :: System :: System Shells",
        'Operating System :: MacOS :: MacOS X',
        "Programming Language :: Python :: 3.8",
        'Operating System :: Microsoft :: Windows',
        "Topic :: System :: Systems Administration",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
    ],
    keywords=['WHOIS', 'RFC', 'Network', 'Domain', 'Registar'],
    platforms=['Windows', 'Linux', "MacOS"],
    license="GPL-3.0 License",
    entry_points = {
        'console_scripts': [
            'SimpleWhois = SimpleWhois:main'
        ],
    },
    python_requires='>=3.8',
)

==> SimpleWhois-0.0.4.tar.gz: SimpleWhois-0.0.4/setup.py <==
from setuptools import setup, find_packages
import SimpleWhois as package

setup(
    name="SimpleWhois",
    version=package.__version__,
    py_modules=["SimpleWhois"],
    packages=find_packages(include=[]),
    install_requires=[],
    scripts=[],
    author="Maurice Lambert",
    author_email="mauricelambert434@gmail.com",
    maintainer="Maurice Lambert",
    maintainer_email="mauricelambert434@gmail.com",
    description="This module implements WHOIS protocol and performs WHOIS requests.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/mauricelambert/SimpleWhois",
    project_urls={
        "Github": "https://github.com/mauricelambert/SimpleWhois",
        "Documentation": "https://mauricelambert.github.io/info/python/code/SimpleWhois.html",
        "Python Executable": "https://mauricelambert.github.io/info/python/code/SimpleWhois.pyz",
        "Windows Executable": "https://mauricelambert.github.io/info/python/code/SimpleWhois.exe",
    },
    download_url="https://mauricelambert.github.io/info/python/code/SimpleWhois.pyz",
    include_package_data=True,
    classifiers=[
        "Topic :: System",
        "Topic :: Software Development :: Libraries",
        "Environment :: Console",
        "Topic :: System :: Shells",
        "Operating System :: POSIX",
        "Natural Language :: English",
        "Topic :: System :: Networking",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "Topic :: System :: System Shells",
        "Operating System :: MacOS :: MacOS X",
        "Programming Language :: Python :: 3.8",
        "Operating System :: Microsoft :: Windows",
        "Topic :: System :: Systems Administration",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
    ],
    keywords=["WHOIS", "RFC", "Network", "Domain", "Registar"],
    platforms=["Windows", "Linux", "MacOS"],
    license="GPL-3.0 License",
    entry_points={
        "console_scripts": ["SimpleWhois = SimpleWhois:main"],
    },
    python_requires=">=3.8",
)
